<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class About_Video_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'about-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About with video section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'About with video section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'v_image',
			[
				'label' => __( 'Video background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src('http://localhost/learnwp/wp-content/uploads/2020/01/4-1.jpg'),
				],
			]
		);
		$this->add_control(
			'video_url',
			[
				'label' => __( 'Video Url', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'v_icon',
			[
				'label' => __( 'Play Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					
                        'flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'flaticon-van' => 'van',
                        'flaticon-truck' => 'truck',
                        'flaticon-dog-bone' => 'dog-bone',
                        'flaticon-bone' => 'bone',
                        'flaticon-dog-3' => 'dog-3',
                        'flaticon-rabbit' => 'rabbit',
                        'flaticon-easter-bunny' => 'easter-bunny',
                        'flaticon-animals-3' => 'animals-3',
                        'flaticon-animals-2' => 'animals-2',
                        'flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'flaticon-man' => 'man',
                        'flaticon-pawprint' => 'pawprint',
                        'flaticon-pawprint-1' => 'pawprint-1',
                        'flaticon-animals-1' => 'animals-1',
                        'flaticon-dog-2' => 'dog-2',
                        'flaticon-cat' => 'cat',
                        'flaticon-dog-1' => 'dog-1',
                        'flaticon-award' => 'award',
                        'flaticon-medal' => 'medal',
                        'flaticon-animal-3' => 'animal-3',
                        'flaticon-animal-2' => 'animal-2',
                        'flaticon-animals' => 'animals',
                        'flaticon-brush' => 'brush',
                        'flaticon-animal-1' => 'animal-1',
                        'flaticon-dog' => 'dog',
                        'flaticon-animal' => 'animal',
                        'flaticon-siberian-husky' => 'siberian-husky',
                        'flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-animals-1',
			]
			
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( ' background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src('http://localhost/learnwp/wp-content/uploads/2020/01/4-1.jpg'),
				],
			]
		);
		$this->add_control(
			'icon1',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					
                        'flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'flaticon-van' => 'van',
                        'flaticon-truck' => 'truck',
                        'flaticon-dog-bone' => 'dog-bone',
                        'flaticon-bone' => 'bone',
                        'flaticon-dog-3' => 'dog-3',
                        'flaticon-rabbit' => 'rabbit',
                        'flaticon-easter-bunny' => 'easter-bunny',
                        'flaticon-animals-3' => 'animals-3',
                        'flaticon-animals-2' => 'animals-2',
                        'flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'flaticon-man' => 'man',
                        'flaticon-pawprint' => 'pawprint',
                        'flaticon-pawprint-1' => 'pawprint-1',
                        'flaticon-animals-1' => 'animals-1',
                        'flaticon-dog-2' => 'dog-2',
                        'flaticon-cat' => 'cat',
                        'flaticon-dog-1' => 'dog-1',
                        'flaticon-award' => 'award',
                        'flaticon-medal' => 'medal',
                        'flaticon-animal-3' => 'animal-3',
                        'flaticon-animal-2' => 'animal-2',
                        'flaticon-animals' => 'animals',
                        'flaticon-brush' => 'brush',
                        'flaticon-animal-1' => 'animal-1',
                        'flaticon-dog' => 'dog',
                        'flaticon-animal' => 'animal',
                        'flaticon-siberian-husky' => 'siberian-husky',
                        'flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-animals-1',
			]
		);
		$this->add_control(
			'title1',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Largest non-profit pet’s shelter')
			]
		);
		$this->add_control(
			'sub_title1',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Well gaudy hound hired inset flailed luxuriant much followed less this maternal oh well unavoidable crudely aloof in more save groomed.')
			]
		);
		$this->add_control(
			'icon2',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					
                        'flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'flaticon-van' => 'van',
                        'flaticon-truck' => 'truck',
                        'flaticon-dog-bone' => 'dog-bone',
                        'flaticon-bone' => 'bone',
                        'flaticon-dog-3' => 'dog-3',
                        'flaticon-rabbit' => 'rabbit',
                        'flaticon-easter-bunny' => 'easter-bunny',
                        'flaticon-animals-3' => 'animals-3',
                        'flaticon-animals-2' => 'animals-2',
                        'flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'flaticon-man' => 'man',
                        'flaticon-pawprint' => 'pawprint',
                        'flaticon-pawprint-1' => 'pawprint-1',
                        'flaticon-animals-1' => 'animals-1',
                        'flaticon-dog-2' => 'dog-2',
                        'flaticon-cat' => 'cat',
                        'flaticon-dog-1' => 'dog-1',
                        'flaticon-award' => 'award',
                        'flaticon-medal' => 'medal',
                        'flaticon-animal-3' => 'animal-3',
                        'flaticon-animal-2' => 'animal-2',
                        'flaticon-animals' => 'animals',
                        'flaticon-brush' => 'brush',
                        'flaticon-animal-1' => 'animal-1',
                        'flaticon-dog' => 'dog',
                        'flaticon-animal' => 'animal',
                        'flaticon-siberian-husky' => 'siberian-husky',
                        'flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-animals-1',
			]
			
		);
		$this->add_control(
			'title2',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Convenient pet adoption for public')
			]
		);
		$this->add_control(
			'sub_title2',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Well gaudy hound hired inset flailed luxuriant much followed less this maternal oh well unavoidable crudely aloof in more save groomed.')
			]
		);
		$this->add_control(
			'icon3',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					
                        'flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'flaticon-van' => 'van',
                        'flaticon-truck' => 'truck',
                        'flaticon-dog-bone' => 'dog-bone',
                        'flaticon-bone' => 'bone',
                        'flaticon-dog-3' => 'dog-3',
                        'flaticon-rabbit' => 'rabbit',
                        'flaticon-easter-bunny' => 'easter-bunny',
                        'flaticon-animals-3' => 'animals-3',
                        'flaticon-animals-2' => 'animals-2',
                        'flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'flaticon-man' => 'man',
                        'flaticon-pawprint' => 'pawprint',
                        'flaticon-pawprint-1' => 'pawprint-1',
                        'flaticon-animals-1' => 'animals-1',
                        'flaticon-dog-2' => 'dog-2',
                        'flaticon-cat' => 'cat',
                        'flaticon-dog-1' => 'dog-1',
                        'flaticon-award' => 'award',
                        'flaticon-medal' => 'medal',
                        'flaticon-animal-3' => 'animal-3',
                        'flaticon-animal-2' => 'animal-2',
                        'flaticon-animals' => 'animals',
                        'flaticon-brush' => 'brush',
                        'flaticon-animal-1' => 'animal-1',
                        'flaticon-dog' => 'dog',
                        'flaticon-animal' => 'animal',
                        'flaticon-siberian-husky' => 'siberian-husky',
                        'flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-animals-1',
			]
		);
		$this->add_control(
			'title3',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Innovative ways to help animals')
			]
		);
		$this->add_control(
			'sub_title3',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Well gaudy hound hired inset flailed luxuriant much followed less this maternal oh well unavoidable crudely aloof in more save groomed.')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<section class="fluid-section-one">
            <div class="outer-container clearfix">
                <!--Image Column-->
                <div class="image-column" style="background-image:url(<?php echo esc_url($settings['v_image']['url']); ?>);">
                    <a class="overlay-box lightbox-image video-btn" href="<?php echo esc_html($settings['video_url']['url']); ?>">
                    <span class="icon-box">
                        <span class="<?php echo esc_html($settings['v_icon']); ?>"></span>
                        <?php echo esc_html('Featured Video'); ?>
                    </span>
                </a>
                    <figure class="image-box"><img src="<?php echo esc_url($settings['v_image']['url']); ?>" alt="img"></figure>
                </div>
                <!--Content Column-->
                <div class="content-column" style="background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)">
                    <div class="inner-column">
                        <div class="featured-block-two">
                            <div class="featured-inner">
                                <div class="icon-box">
                                    <span class="<?php echo esc_html($settings['icon1']); ?>"></span>
                                </div>
                                <h3><?php echo esc_html($settings['title1']); ?></h3>
                                <div class="text"><?php echo esc_html($settings['sub_title1']); ?></div>
                            </div>
                        </div>
                        <div class="featured-block-two">
                            <div class="featured-inner">
                                <div class="icon-box">
                                    <span class="<?php echo esc_html($settings['icon2']); ?>"></span>
                                </div>
                                <h3><?php echo esc_html($settings['title2']); ?> </h3>
                                <div class="text"><?php echo esc_html($settings['sub_title2']); ?></div>
                            </div>
                        </div>
                        <div class="featured-block-two">
                            <div class="featured-inner">
                                <div class="icon-box">
                                    <span class="<?php echo esc_html($settings['icon3']); ?>"></span>
                                </div>
                                <h3><?php echo esc_html($settings['title3']); ?></h3>
                                <div class="text"><?php echo esc_html($settings['sub_title3']); ?></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>