<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Appointment_Vet extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'appointment-vet';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Appointment Vet', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Appointment Vet setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( ' background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Pets Available For Adoption')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('More forwardly pangolin however .')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
<section class="appointment-section appointment-4" style="background-image:url(<?php echo esc_url($settings['bg_image']['url']); ?>); background-size: cover;">
    <div class="auto-container">
        <!--Sec Title-->
        <div class="sec-title light centered">
            <h2><?php echo $settings['s_title']; ?></h2>
            <div class="title"><?php echo $settings['title']; ?></div>
        </div>

        <!--Default Form-->
        <div class="default-form wow">
            <div class="form-box">
               <?php echo do_shortcode('[cmb_frontend_form]'); ?>
            </div>
        </div>
        <!--End Default Form-->

    </div>
</section> 
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>