<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Appointment_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Appointment-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Appointment Section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Appointment section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Chose Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
		$this->add_control(
			'a_icon',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					
                        'flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'flaticon-van' => 'van',
                        'flaticon-truck' => 'truck',
                        'flaticon-dog-bone' => 'dog-bone',
                        'flaticon-bone' => 'bone',
                        'flaticon-dog-3' => 'dog-3',
                        'flaticon-rabbit' => 'rabbit',
                        'flaticon-easter-bunny' => 'easter-bunny',
                        'flaticon-animals-3' => 'animals-3',
                        'flaticon-animals-2' => 'animals-2',
                        'flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'flaticon-man' => 'man',
                        'flaticon-pawprint' => 'pawprint',
                        'flaticon-pawprint-1' => 'pawprint-1',
                        'flaticon-animals-1' => 'animals-1',
                        'flaticon-dog-2' => 'dog-2',
                        'flaticon-cat' => 'cat',
                        'flaticon-dog-1' => 'dog-1',
                        'flaticon-award' => 'award',
                        'flaticon-medal' => 'medal',
                        'flaticon-animal-3' => 'animal-3',
                        'flaticon-animal-2' => 'animal-2',
                        'flaticon-animals' => 'animals',
                        'flaticon-brush' => 'brush',
                        'flaticon-animal-1' => 'animal-1',
                        'flaticon-dog' => 'dog',
                        'flaticon-animal' => 'animal',
                        'flaticon-siberian-husky' => 'siberian-husky',
                        'flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-animals-1',
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Get An Appointment')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Because We Really Care About Your Pets')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<section class="appointment-section" style="background-size: cover; background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)">
            <div class="auto-container">
                <!--Sec Title-->
                <div class="sec-title light centered">
                    <div class="separator">
                        <span class="<?php echo esc_html($settings['a_icon']); ?>"></span>
                    </div>
                    <div class="title"><?php echo esc_html($settings['s_title']); ?></div>
                    <h2><?php echo esc_html($settings['title']); ?></h2>
                </div>
                <!--Default Form-->
                <div class="default-form">
                    <div class="form-box">
                        <?php echo do_shortcode('[cmb_frontend_form]'); ?>
                    </div>
                </div>
                <!--End Default Form-->
            </div>
        </section>
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>