<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Calculator extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'calculator-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'calculator section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'History section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'small_title',
			[
				'label' => __( 'Small Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Well gaudy hound hired.')
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Largest non-profit pet’s shelter')
			]
		);
				$this->add_control(
			'btn_url',
			[
				'label' => __( 'Button Url', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
				$this->add_control(
			'btn_title',
			[
				'label' => __( 'Button Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Read More')
			]
		);
				$this->add_control(
			'l_image',
			[
				'label' => __( 'Left Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
				$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
<div class="calories-calulator">
            <div class="auto-container">
                    <!--Sec Title-->
                    <div class="sec-title centered">
                        <div class="separator">
                            <span class="icon flaticon-pawprint-1"></span>
                        </div>
                        <div class="title"><?php echo esc_html($settings['small_title']); ?></div>
                        <h2><?php echo esc_html($settings['title']); ?></h2>
                    </div>
                    <div class="row">
                    	<div class="col-md-1"></div>
                    <div class="col-md-8 col-md-offset-1 col-sm-12 cal_outer">
                        <ul class="nav nav-tabs">
                            <li class="active"><a data-toggle="tab" href="#home"><?php esc_html_e('Dog' , 'petenica-core' ); ?></a></li>
                            <li><a data-toggle="tab" href="#menu1"><?php esc_html_e( 'Cat', 'petenica-core' ); ?></a></li>
                        </ul>
                        <div class="tab-content">
                            <div id="home" class="tab-pane fade in active">
                                <h3><?php esc_html_e( 'Dog Feed Calculator', 'petenica-core' ); ?></h3>
                                <div class="pet_img">
                                    
										<i class="flaticon-dog-3"></i>
									
                                </div>
                                <p>
                                	<form id="dogcal">
                                    <div class="row">
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="weightlbs"><?php esc_html_e( 'Your Name', 'petenica-core' ); ?></label>
                                                <input type="text" class="form-control" id="parent_name" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="weightlbs"><?php esc_html_e( 'Your Email', 'petenica-core' ); ?></label>
                                                <input type="email" class="form-control" id="parent_email" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="weightlbs"><?php esc_html_e( 'Dog Name', 'petenica-core' ); ?></label>
                                                <input type="text" class="form-control" id="dog_name" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="weightlbs"><?php esc_html_e( 'Dog Gender', 'petenica-core' ); ?> <span>*</span></label>
                                                <input type="radio" id="option2" name="selector" checked="" required>
                                                <label class="gender"><?php esc_html_e( 'Male', 'petenica-core' ); ?></label>
                                                <input type="radio" id="option2" name="selector" checked="" required>
                                                <label class="gender"><?php esc_html_e( 'Female', 'petenica-core' ); ?></label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <label for="weightlbs"><?php esc_html_e( 'Weight', 'petenica-core' ); ?> <span>*</span></label>
                                        <input type="text" class="form-control" id="weightlbs" aria-describedby="emailHelp" placeholder="Enter Weight" required>
                                        <small id="emailHelp" class="form-text text-muted"><?php esc_html_e( 'Enter Weight In Pounds', 'petenica-core' ); ?></small>
                                    </div>
                                    <div class="form-group">
                                        <label for="dogactivity"><?php esc_html_e( 'Select Dog Activity', 'petenica-core' ); ?> <span>*</span></label>
                                        <select class="form-control" id="dogactivity" required>
                                            <option value="90"><?php esc_html_e( 'Inactive/Senior', 'petenica-core' ); ?></option>
                                            <option value="110"><?php esc_html_e( 'Typical', 'petenica-core' ); ?></option>
                                            <option value="125"><?php esc_html_e( 'Active', 'petenica-core' ); ?></option>
                                            <option value="175"><?php esc_html_e( 'Highly Active', 'petenica-core' ); ?></option>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <label for="dogbreed"><?php esc_html_e( 'Select Dog Breed ', 'petenica-core' ); ?><span>*</span></label>
                                        <select class="form-control" id="dogbreed" required>
                                            <option value="Select Breed"><?php esc_html_e( 'Select Breed', 'petenica-core' ); ?></option>
                                            <option value="Affenpinscher">Affenpinscher</option>
                                            <option value="Afghan Hound">Afghan Hound</option>
                                            <option value="Airedale Terrier">Airedale Terrier</option>
                                            <option value="Akita">Akita</option>
                                            <option value="Alaskan Malamute">Alaskan Malamute</option>
                                            <option value="American English Coonhound">American English Coonhound</option>
                                            <option value="American Eskimo Dog">American Eskimo Dog</option>
                                            <option value="American Foxhound">American Foxhound</option>
                                            <option value="American Hairless Terrier">American Hairless Terrier</option>
                                            <option value="American Leopard Hound">American Leopard Hound</option>
                                            <option value="American Staffordshire Terrier">American Staffordshire Terrier</option>
                                            <option value="American Water Spaniel">American Water Spaniel</option>
                                            <option value="Anatolian Shepherd Dog">Anatolian Shepherd Dog</option>
                                            <option value="Appenzeller Sennenhunde">Appenzeller Sennenhunde</option>
                                            <option value="Australian Cattle Dog">Australian Cattle Dog</option>
                                            <option value="Australian Shepherd">Australian Shepherd</option>
                                            <option value="Australian Terrier">Australian Terrier</option>
                                            <option value="Azawakh">Azawakh</option>
                                            <option value="Barbet">Barbet</option>
                                            <option value="Basenji">Basenji</option>
                                            <option value="Basset Hound">Basset Hound</option>
                                            <option value="Beagle">Beagle</option>
                                            <option value="Bearded Collie">Bearded Collie</option>
                                            <option value="Beauceron">Beauceron</option>
                                            <option value="Bedlington Terrier">Bedlington Terrier</option>
                                            <option value="Belgian Laekenois">Belgian Laekenois</option>
                                            <option value="Belgian Malinois">Belgian Malinois</option>
                                            <option value="Belgian Sheepdog">Belgian Sheepdog</option>
                                            <option value="Belgian Tervuren">Belgian Tervuren</option>
                                            <option value="Bergamasco">Bergamasco</option>
                                            <option value="Berger Picard">Berger Picard</option>
                                            <option value="Bernese Mountain Dog">Bernese Mountain Dog</option>
                                            <option value="Bichon Frise">Bichon Frise</option>
                                            <option value="Biewer Terrier">Biewer Terrier</option>
                                            <option value="Black and Tan Coonhound">Black and Tan Coonhound</option>
                                            <option value="Black Russian Terrier">Black Russian Terrier</option>
                                            <option value="Bloodhound">Bloodhound</option>
                                            <option value="Bluetick Coonhound">Bluetick Coonhound</option>
                                            <option value="Boerboel">Boerboel</option>
                                            <option value="Bolognese">Bolognese</option>
                                            <option value="Border Collie">Border Collie</option>
                                            <option value="Border Terrier">Border Terrier</option>
                                            <option value="Borzoi">Borzoi</option>
                                            <option value="Boston Terrier">Boston Terrier</option>
                                            <option value="Bouvier des Flandres">Bouvier des Flandres</option>
                                            <option value="Boxer">Boxer</option>
                                            <option value="Boykin Spaniel">Boykin Spaniel</option>
                                            <option value="Bracco Italiano">Bracco Italiano</option>
                                            <option value="Braque du Bourbonnais">Braque du Bourbonnais</option>
                                            <option value="Briard">Briard</option>
                                            <option value="Brittany">Brittany</option>
                                            <option value="Broholmer">Broholmer</option>
                                            <option value="Brussels Griffon">Brussels Griffon</option>
                                            <option value="Bull Terrier">Bull Terrier</option>
                                            <option value="Bulldog">Bulldog</option>
                                            <option value="Bullmastiff">Bullmastiff</option>
                                            <option value="Cairn Terrier">Cairn Terrier</option>
                                            <option value="Canaan Dog">Canaan Dog</option>
                                            <option value="Cane Corso">Cane Corso</option>
                                            <option value="Cardigan Welsh Corgi">Cardigan Welsh Corgi</option>
                                            <option value="Catahoula Leopard Dog">Catahoula Leopard Dog</option>
                                            <option value="Caucasian Ovcharka">Caucasian Ovcharka</option>
                                            <option value="Cavalier King Charles Spaniel">Cavalier King Charles Spaniel</option>
                                            <option value="Central Asian Shepherd Dog">Central Asian Shepherd Dog</option>
                                            <option value="Cesky Terrier">Cesky Terrier</option>
                                            <option value="Chesapeake Bay Retriever">Chesapeake Bay Retriever</option>
                                            <option value="Chihuahua">Chihuahua</option>
                                            <option value="Chinese Crested">Chinese Crested</option>
                                            <option value="Chinese Shar-Pei">Chinese Shar-Pei</option>
                                            <option value="Chinook">Chinook</option>
                                            <option value="Chow Chow">Chow Chow</option>
                                            <option value="Cirneco dellEtna">Cirneco dellEtna</option>
                                            <option value="Clumber Spaniel">Clumber Spaniel</option>
                                            <option value="Cocker Spaniel">Cocker Spaniel</option>
                                            <option value="Collie">Collie</option>
                                            <option value="Coton de Tulear">Coton de Tulear</option>
                                            <option value="Curly-Coated Retriever">Curly-Coated Retriever</option>
                                            <option value="Czechoslovakian Vlcak">Czechoslovakian Vlcak</option>
                                            <option value="Dachshund">Dachshund</option>
                                            <option value="Dalmatian">Dalmatian</option>
                                            <option value="Dandie Dinmont Terrier">Dandie Dinmont Terrier</option>
                                            <option value="Danish-Swedish Farmdog">Danish-Swedish Farmdog</option>
                                            <option value="Deutscher Wachtelhund">Deutscher Wachtelhund</option>
                                            <option value="Doberman Pinscher">Doberman Pinscher</option>
                                            <option value="Dogo Argentino">Dogo Argentino</option>
                                            <option value="Dogue de Bordeaux">Dogue de Bordeaux</option>
                                            <option value="Drentsche Patrijshond">Drentsche Patrijshond</option>
                                            <option value="Drever">Drever</option>
                                            <option value="Dutch Shepherd">Dutch Shepherd</option>
                                            <option value="English Cocker Spaniel">English Cocker Spaniel</option>
                                            <option value="English Foxhound">English Foxhound</option>
                                            <option value="English Setter">English Setter</option>
                                            <option value="English Springer Spaniel">English Springer Spaniel</option>
                                            <option value="English Toy Spaniel">English Toy Spaniel</option>
                                            <option value="Entlebucher Mountain Dog">Entlebucher Mountain Dog</option>
                                            <option value="Estrela Mountain Dog">Estrela Mountain Dog</option>
                                            <option value="Eurasier">Eurasier</option>
                                            <option value="Field Spaniel">Field Spaniel</option>
                                            <option value="Finnish Lapphund">Finnish Lapphund</option>
                                            <option value="Finnish Spitz">Finnish Spitz</option>
                                            <option value="Flat-Coated Retriever">Flat-Coated Retriever</option>
                                            <option value="French Bulldog">French Bulldog</option>
                                            <option value="French Spaniel">French Spaniel</option>
                                            <option value="German Longhaired Pointer">German Longhaired Pointer</option>
                                            <option value="German Pinscher">German Pinscher</option>
                                            <option value="German Shepherd Dog">German Shepherd Dog</option>
                                            <option value="German Shorthaired Pointer">German Shorthaired Pointer</option>
                                            <option value="German Spitz">German Spitz</option>
                                            <option value="German Wirehaired Pointer">German Wirehaired Pointer</option>
                                            <option value="Giant Schnauzer">Giant Schnauzer</option>
                                            <option value="Glen of Imaal Terrier">Glen of Imaal Terrier</option>
                                            <option value="Golden Retriever">Golden Retriever</option>
                                            <option value="Gordon Setter">Gordon Setter</option>
                                            <option value="Grand Basset Griffon Vendeen">Grand Basset Griffon Vendeen</option>
                                            <option value="Great Dane">Great Dane</option>
                                            <option value="Great Pyrenees">Great Pyrenees</option>
                                            <option value="Greater Swiss Mountain Dog">Greater Swiss Mountain Dog</option>
                                            <option value="Greyhound">Greyhound</option>
                                            <option value="Hamiltonstovare">Hamiltonstovare</option>
                                            <option value="Harrier">Harrier</option>
                                            <option value="Havanese">Havanese</option>
                                            <option value="Hovawart">Hovawart</option>
                                            <option value="Ibizan Hound">Ibizan Hound</option>
                                            <option value="Icelandic Sheepdog">Icelandic Sheepdog</option>
                                            <option value="Other"> Other</option>
                                        </select>
                                    </div>
                                    <input class="button" type="submit" value="<?php esc_html_e( 'Calculate', 'petenica-core' ); ?>">
                                    
                                    </form>
                                    <h1 id="dogtotalcal"></h1>
                                    <a href="#" class="theme-btn btn-style-two"  id="backbtn"><?php esc_html_e( 'Calculate Again', 'petenica-core' ); ?></a>
                                    <script type="text/javascript">                                  
                                    jQuery(document).ready(function() {
                                    	jQuery('#backbtn').hide();
									    jQuery('#dogcal').submit(function(e){
									    e.preventDefault();

									    var weight = document.getElementById('weightlbs').value;
									    var name = document.getElementById('dog_name').value;
									    var dogactivity = document.getElementById('dogactivity').value;
                                        var weightkg = weight * .4536;

									    var dogactivityv = (Math.pow(weightkg, .75)) * document.getElementById('dogactivity').value;

									    jQuery("#dogtotalcal").html(name + " <?php esc_html_e( 'needs', 'petenica-core' ); ?> "+  Math.round(dogactivityv)+" <?php esc_html_e( 'calories per day', 'petenica-core' ); ?> " );
									    jQuery("#dogtotalcal").show();
									    jQuery("#dogcal").hide();
									    jQuery('#backbtn').show();
									    
									    return false;
									    });
									    jQuery('#backbtn').on('click' , function(){
									    	jQuery("#dogtotalcal").hide();
									    	jQuery("#dogcal").show();
									    	jQuery('#backbtn').hide();
									    	document.getElementById('dogcal').reset();
									    });
									});
                                    </script>
                                </p>
                            </div>
                            <div id="menu1" class="tab-pane fade">
                                <h3><?php esc_html_e( 'Cat Feed Calculator', 'petenica-core' ); ?></h3>
                                <div class="pet_img">
                                    <i class="flaticon-cat"></i>
                                </div>
                                <form id="catform">
                                	
                               
                                        <div class="row">
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="yourname"><?php esc_html_e( 'Your Name', 'petenica-core' ); ?></label>
                                                <input type="text" class="form-control" id="parent_name" name="yourname" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="youremail"><?php esc_html_e( 'Your Email', 'petenica-core' ); ?></label>
                                                <input type="email" class="form-control" id="parent_email" name="youremail" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="catname"><?php esc_html_e( 'Cat Name', 'petenica-core' ); ?></label>
                                                <input type="name" class="form-control" id="catname" name="catname" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-sm-12">
                                            <div class="form-group">
                                                <label for="selector"><?php esc_html_e( 'Cat Gender', 'petenica-core' ); ?> <span>*</span></label>
                                                <input type="radio" id="option2" name="selector" checked="">
                                                <label class="gender"><?php esc_html_e( 'Male', 'petenica-core' ); ?></label>
                                                <input type="radio" id="option2" name="selector" checked="">
                                                <label class="gender"><?php esc_html_e( 'Female', 'petenica-core' ); ?></label>
                                            </div>
                                        </div>
                                    </div>
                                        <div class="form-group">
                                            <label for="weightlb"><?php esc_html_e( 'Weight', 'petenica-core' ); ?> <span>*</span></label>
                                            <input type="text" class="form-control" id="weightlb" aria-describedby="emailHelp" placeholder="Enter Weight" required>
                                            <small id="emailHelp" class="form-text text-muted"><?php esc_html_e( 'Enter Weight In Pounds', 'petenica-core' ); ?></small>
                                        </div>
                                        <div class="form-group">
                                            <label for="exampleFormControlSelect1"><?php esc_html_e( 'Select Weight', 'petenica-core' ); ?> <span>*</span></label>
                                            <select class="form-control" id="exampleFormControlSelect1" >
                                                <option value="1.2"><?php esc_html_e( 'Same Weight', 'petenica-core' ); ?></option>
                                                <option value=".9"><?php esc_html_e( 'Weight Reduction', 'petenica-core' ); ?></option>
                                            </select>
                                        </div>
                                        <input class="button" type="submit" value="<?php esc_html_e( 'Calculate', 'petenica-core' ); ?>">
                                         </form>
                                        <h1 id="totalcal"></h1>
                                        <a href="#" class="theme-btn btn-style-two" id="backbtncat"><?php esc_html_e( 'Calculate Again', 'petenica-core' ); ?></a>
                                        <script type="text/javascript">
                                        function get_cat_calories() {
                                            //Here we get the total price by calling our function
                                            //Each function returns a number so by calling them we add the values they return together
                                            var weight = document.getElementById('weightlb').value;
                                            var weightkg = weight * .4536;
                                            var cakePrice = (Math.pow(weightkg, .75)) * 70 * document.getElementById('exampleFormControlSelect1').value;

                                            //display the result
                                            document.getElementById('totalcal').innerHTML =
                                                "Total calories need per day for your cat " + Math.round(cakePrice);

                                        }
                                        jQuery(document).ready(function() {
                                    	jQuery('#backbtncat').hide();
									    jQuery('#catform').submit(function(e){
									    e.preventDefault();

									    var weight = document.getElementById('weightlb').value;
									    var name = document.getElementById('catname').value;
                                        var weightkg = weight * .4536;

									    var catactivity = (Math.pow(weightkg, .75))* 70 * document.getElementById('exampleFormControlSelect1').value;

									    jQuery("#totalcal").html(name + " <?php esc_html_e( 'needs', 'petenica-core' ); ?> "+  Math.round(catactivity)+" <?php esc_html_e( 'calories per day', 'petenica-core' ); ?> " );
									    jQuery("#totalcal").show();
									    jQuery("#catform").hide();
									    jQuery('#backbtncat').show();
									    
									    return false;
									    });
									    jQuery('#backbtncat').on('click' , function(){
									    	jQuery("#totalcal").hide();
									    	jQuery("#catform").show();
									    	jQuery('#backbtncat').hide();
									    	document.getElementById('catform').reset();
									    });
									});
                                        </script>
                                   
                            </div>
                        </div>
                    </div>
                    </div>
            </div>
        </div>
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>