<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Contact_Form extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'contact-form';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact Form', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);
		$cf7_forms = array('0' => 'Select Form ID');
		if ($cf7Forms = get_posts($args)) {
			foreach ($cf7Forms as $cf7Form) {
				$cf7_forms[$cf7Form->ID] = $cf7Form->post_title;
				//echo(do_shortcode('[contact-form-7 id="'.$cf7Form->ID.'" title="'.($cf7Form->post_title).'"]'));
			}
		}
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Contact form setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Get In Touch')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Capitalize on low hanging fruit to identify a ballpark value added activity to beta test.')
			]
		);
		$this->add_control(
			'text2',
			[
				'label' => __( 'Contact details ', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::WYSIWYG,
				'default' => ('<li><span>Address:</span>52A, Tailstoi Town 5238 <br> La city, IA 85796</li>
                            <li><span>Phone:</span>0000 000 0000</li>
                            <li><span>email:</span>info@petinica.com</li>
                            ')
			]
		);
		$this->add_control(
			'cf7',
			[
				'label' => esc_html__('Select Newsletter Form', 'sinaeat'),
				'type' =>\Elementor\Controls_Manager::SELECT,
				'options' => $cf7_forms,
				'label_block' => true,
				'multiple' => true,
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$cform7 = '[contact-form-7 id="' . $settings['cf7'] . '"]';

		?>
		<section class="contact-section">
    	<div class="auto-container">
        	<div class="sec-title">
        		<h2><?php echo esc_html($settings['title']); ?></h2>
                        <p></p>
        		<h2></h2>
            	<div class="title"><?php echo esc_html($settings['s_title']); ?></div>
            </div>
        	<div class="row clearfix">
            	<!--Form Column-->
            	<div class="form-column col-md-7 col-sm-12 col-xs-12">
                    <div class="contact-form">
                    	 <?php echo do_shortcode($cform7); ?>
                    </div>
                </div>
                <!--Info Column-->
                <div class="info-column col-md-5 col-sm-12 col-xs-12">
                	<div class="inner-column">
                    	<ul>
                        	<?php echo ($settings['text2']); ?>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </section>
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>