<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Counter_Section extends \Elementor\Widget_Base {

	public function get_name() {
		return 'counter';
	}

	public function get_title() {
		return __( 'Counter', 'elementor' );
	}
	public function get_categories() {
		return [ 'custom' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Counter', 'petenica-core' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('We Offers The Best Pet Care Solutions')
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
	
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Counter section setting', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'List Title' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'count', [
				'label' => __( 'Count to', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '748' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::ICON,
				'include' => [
					'icon flaticon-dog-bone',
					'icon flaticon-animals-2',
					'icon flaticon-dog-in-front-of-a-man',
					'icon flaticon-pet-grooming',
				],
				'default' => 'icon flaticon-dog-bone',
			]
		);
		$repeater->add_control(
			'text', [
				'label' => __( 'Text', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Pet Adoptions' , 'petenica-core' ),
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Repeater List', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		
		?>
		 <section class="counter-section">
            <div class="auto-container">
                <div class="image-layer" style="background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)"></div>
                <h2><?php echo esc_html($settings['title']); ?></h2>
                <div class="counter-box">
                    <div class="fact-counter">
                        <div class="row clearfix">
                            <?php if($settings['list']){
                            	foreach($settings['list'] as $item){?>
                                  <div class="column counter-column col-md-3 col-sm-6 col-xs-12">
                                <div class="inner">
                                    <div class="icon-box">
                                        <span class="<?php echo esc_html($item['icon']); ?>"></span>
                                    </div>
                                    <div class="count-outer count-box">
                                        <span class="count-text" data-speed="2000" data-stop="<?php echo esc_html($item['count']); ?>">0</span>
                                    </div>
                                    <h4 class="counter-title"><?php echo esc_html($item['text']); ?></h4>
                                </div>
                            </div>
                            <?php
                            	}
                            } ?>
                            
                        </div>
                    </div>
                </div>
            </div>
        </section>
		<?php
	}

	protected function _content_template() {
		?>
		<# if ( settings.list.length ) { #>
		<dl>
			<# _.each( settings.list, function( item ) { #>
				<dt class="elementor-repeater-item-{{ item._id }}">{{{ item.list_title }}}</dt>
				<dd>{{{ item.text }}}</dd>
			<# }); #>
			</dl>
		<# } #>
		<?php
	}
}
?>