<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Deal_Product_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Deal product-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Deal Product section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Deal Product section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<?php $args = array('post_type' => 'product',
	                        'posts_per_page' => -1); ?>
	    <?php $post = new WP_Query($args); ?>                    
	    <section class="discount-section">
    	<div class="auto-container">
        	<div class="inner-container" style="background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)">
            	<div class="content">
                    <?php 
                    $i = 1;
                    while($post->have_posts()) : $post->the_post(); 
                    	global $product;
                    $isdeal = get_post_meta( get_the_ID(), 'isdeal', true );
                    ?>
                    <?php if ($isdeal): ?>
                	<div class="deal"><?php the_title(); ?></div>
                    <h2><?php echo get_post_meta( get_the_ID(), 'itemtitle', true ); ?></h2>
                    <div class="discount-price"><?php echo $product->get_price_html(); ?></div>
                    <div class="text"><?php the_excerpt(); ?></div>
                    <div class="time-counter"><div class="time-countdown clearfix" data-countdown="<?php echo get_post_meta( get_the_ID(), 'enddate', true ); ?>"></div></div>
                    <a href="<?php the_permalink(); ?>" class="theme-btn btn-style-nine">view details</a>
                <?php endif ?>
                <?php $i++; endwhile; ?>
                </div>
            </div>
        </div>
    </section>                  
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>