<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Feature_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'feature-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Feature section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Feature section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
		$this->add_control(
			'icon1',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'icon flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'icon flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'icon flaticon-van' => 'van',
                        'icon flaticon-truck' => 'truck',
                        'icon flaticon-dog-bone' => 'dog-bone',
                        'icon flaticon-bone' => 'bone',
                        'icon flaticon-dog-3' => 'dog-3',
                        'icon flaticon-rabbit' => 'rabbit',
                        'icon flaticon-easter-bunny' => 'easter-bunny',
                        'icon flaticon-animals-3' => 'animals-3',
                        'icon flaticon-animals-2' => 'animals-2',
                        'icon flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'icon flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'icon flaticon-man' => 'man',
                        'icon flaticon-pawprint' => 'pawprint',
                        'icon flaticon-pawprint-1' => 'pawprint-1',
                        'icon flaticon-animals-1' => 'animals-1',
                        'icon flaticon-dog-2' => 'dog-2',
                        'icon flaticon-cat' => 'cat',
                        'icon flaticon-dog-1' => 'dog-1',
                        'icon flaticon-award' => 'award',
                        'icon flaticon-medal' => 'medal',
                        'icon flaticon-animal-3' => 'animal-3',
                        'icon flaticon-animal-2' => 'animal-2',
                        'icon flaticon-animals' => 'animals',
                        'icon flaticon-brush' => 'brush',
                        'icon flaticon-animal-1' => 'animal-1',
                        'icon flaticon-dog' => 'dog',
                        'icon flaticon-animal' => 'animal',
                        'icon flaticon-siberian-husky' => 'siberian-husky',
                        'icon flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-pawprint-1',
			]
		);
		$this->add_control(
			'link1',
			[
				'label' => __( 'Link', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'title1',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('we heal pets')
			]
		);
		$this->add_control(
			's_title1',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('quick veterinary services')
			]
		);
		$this->add_control(
			'icon2',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'icon flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'icon flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'icon flaticon-van' => 'van',
                        'icon flaticon-truck' => 'truck',
                        'icon flaticon-dog-bone' => 'dog-bone',
                        'icon flaticon-bone' => 'bone',
                        'icon flaticon-dog-3' => 'dog-3',
                        'icon flaticon-rabbit' => 'rabbit',
                        'icon flaticon-easter-bunny' => 'easter-bunny',
                        'icon flaticon-animals-3' => 'animals-3',
                        'icon flaticon-animals-2' => 'animals-2',
                        'icon flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'icon flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'icon flaticon-man' => 'man',
                        'icon flaticon-pawprint' => 'pawprint',
                        'icon flaticon-pawprint-1' => 'pawprint-1',
                        'icon flaticon-animals-1' => 'animals-1',
                        'icon flaticon-dog-2' => 'dog-2',
                        'icon flaticon-cat' => 'cat',
                        'icon flaticon-dog-1' => 'dog-1',
                        'icon flaticon-award' => 'award',
                        'icon flaticon-medal' => 'medal',
                        'icon flaticon-animal-3' => 'animal-3',
                        'icon flaticon-animal-2' => 'animal-2',
                        'icon flaticon-animals' => 'animals',
                        'icon flaticon-brush' => 'brush',
                        'icon flaticon-animal-1' => 'animal-1',
                        'icon flaticon-dog' => 'dog',
                        'icon flaticon-animal' => 'animal',
                        'icon flaticon-siberian-husky' => 'siberian-husky',
                        'icon flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-pawprint-1',
			]
		);
		$this->add_control(
			'link2',
			[
				'label' => __( 'Link', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'title2',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('we care pets')
			]
		);
		$this->add_control(
			's_title2',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('pet sheltering & adoption')
			]
		);
		$this->add_control(
			'icon3',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'icon flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'icon flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'icon flaticon-van' => 'van',
                        'icon flaticon-truck' => 'truck',
                        'icon flaticon-dog-bone' => 'dog-bone',
                        'icon flaticon-bone' => 'bone',
                        'icon flaticon-dog-3' => 'dog-3',
                        'icon flaticon-rabbit' => 'rabbit',
                        'icon flaticon-easter-bunny' => 'easter-bunny',
                        'icon flaticon-animals-3' => 'animals-3',
                        'icon flaticon-animals-2' => 'animals-2',
                        'icon flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'icon flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'icon flaticon-man' => 'man',
                        'icon flaticon-pawprint' => 'pawprint',
                        'icon flaticon-pawprint-1' => 'pawprint-1',
                        'icon flaticon-animals-1' => 'animals-1',
                        'icon flaticon-dog-2' => 'dog-2',
                        'icon flaticon-cat' => 'cat',
                        'icon flaticon-dog-1' => 'dog-1',
                        'icon flaticon-award' => 'award',
                        'icon flaticon-medal' => 'medal',
                        'icon flaticon-animal-3' => 'animal-3',
                        'icon flaticon-animal-2' => 'animal-2',
                        'icon flaticon-animals' => 'animals',
                        'icon flaticon-brush' => 'brush',
                        'icon flaticon-animal-1' => 'animal-1',
                        'icon flaticon-dog' => 'dog',
                        'icon flaticon-animal' => 'animal',
                        'icon flaticon-siberian-husky' => 'siberian-husky',
                        'icon flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-pawprint-1',
			]
		);
		$this->add_control(
			'link3',
			[
				'label' => __( 'Link', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'title3',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('we love pets')
			]
		);
		$this->add_control(
			's_title3',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Show love & donate us')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<section class="featured-section" style="background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)">
            <div class="auto-container">
                <div class="row clearfix">
                    <!--Featured Block-->
                    <div class="featured-block col-md-4 col-sm-6 col-xs-12">
                        <div class="inner-box wow fadeInLeft animated" data-wow-duration="500ms" data-wow-delay="0ms" style="visibility: visible; animation-duration: 500ms; animation-delay: 0ms; animation-name: fadeInLeft;">
                            <div class="content">
                                <div class="icon-box">
                                    <span class="<?php echo esc_html($settings['icon1']); ?>"></span>
                                </div>
                                <h3><a href="<?php echo esc_html($settings['link1']); ?>"><?php echo esc_html($settings['title1']); ?></a></h3>
                                <div class="text"><?php echo esc_html($settings['s_title1']); ?></div>
                            </div>
                        </div>
                    </div>
                    <!--Featured Block-->
                    <div class="featured-block col-md-4 col-sm-6 col-xs-12">
                        <div class="inner-box wow fadeInLeft animated" data-wow-duration="1500ms" data-wow-delay="0ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 0ms; animation-name: fadeInLeft;">
                            <div class="content">
                                <div class="icon-box">
                                    <span class="<?php echo esc_html($settings['icon2']); ?>"></span>
                                </div>
                                <h3><a href="<?php echo esc_html($settings['link2']); ?>"><?php echo esc_html($settings['title2']); ?></a></h3>
                                <div class="text"><?php echo esc_html($settings['s_title2']); ?></div>
                            </div>
                        </div>
                    </div>
                    <!--Featured Block-->
                    <div class="featured-block col-md-4 col-sm-6 col-xs-12">
                        <div class="inner-box wow fadeInLeft animated" data-wow-duration="2500ms" data-wow-delay="0ms" style="visibility: visible; animation-duration: 2500ms; animation-delay: 0ms; animation-name: fadeInLeft;">
                            <div class="content">
                                <div class="icon-box">
                                    <span class="<?php echo esc_html($settings['icon3']); ?>"></span>
                                </div>
                                <h3><a href="<?php echo esc_html($settings['link3']); ?>"><?php echo esc_html($settings['title3']); ?></a></h3>
                                <div class="text"><?php echo esc_html($settings['s_title3']); ?></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>