<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class Gallery_Section extends \Elementor\Widget_Base {

	public function get_name() {
		return 'gallery';
	}

	public function get_title() {
		return __( 'Gallery section', 'elementor' );
	}
	public function get_categories() {
		return [ 'custom' ];
	}

	protected function register_controls() {
		  $this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Gallery section setting', 'petenica-core' ),
			]
		   );
		  $this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Works Gallery')
			]
		   );
		  $this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('For professional dog and cat grooming needs')
			]
		  );
	    $this->end_controls_section();

	    //Start repetor control

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Set Prices', 'plugin-name' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Select Images', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'List Title' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
				'show' => 'false',
			]
		);
		$this->add_control(
			'list',
			[
				'label' => __( 'Repeater List', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
         <section class="gallery-section">
        <div class="auto-container">
            <!--Sec Title Two-->
            <div class="sec-title-two centered">
                <div class="title-icon">
                    <img src="<?php echo get_template_directory_uri(); ?>/framework/assets/images/icons/title-icon.png" alt="img" />
                </div>
                <h2><?php echo esc_html($settings['title']); ?></h2>
                <div class="text"><?php echo esc_html($settings['s_title']); ?></div>
            </div>
            <div class="row clearfix">
            	<?php if( $settings['list'] ) {
                		foreach($settings['list'] as $item) {?>
                    <div class="gallery-item col-md-4 col-sm-6 col-xs-12">
                    <div class="inner-box">
                        <figure class="image-box">
                            <img src="<?php echo esc_html($item['image']['url']); ?>" alt="img">
                            <!--Overlay Box-->
                            <div class="overlay-box">
                                <div class="overlay-inner">
                                    <div class="content">
                                        <a href="<?php echo esc_html($item['image']['url']); ?>" data-fancybox="images" data-caption="" class="link"><span class="icon fa fa-search"></span></a>
                                    </div>
                                </div>
                            </div>
                        </figure>
                    </div>
                </div>
                <?php }} ?>
            </div>
        </div>
    </section>
	<?php }
	protected function _content_template() {
		?>
		<# if ( settings.list.length ) { #>
		<dl>
			<# _.each( settings.list, function( item ) { #>
				<dt class="elementor-repeater-item-{{ item._id }}">{{{ item.list_title }}}</dt>
				<dd>{{{ item.list_content }}}</dd>
			<# }); #>
			</dl>
		<# } #>
		<?php
	}
}