<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Info_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'info-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Info section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$args = array('post_type' => 'mc4wp-form', 'posts_per_page' => -1);
        $mc_forms = array('0' =>'Select Form ID');
        if( $mcForms = get_posts( $args ) ){
            foreach($mcForms as $mcForm){
                $mc_forms[$mcForm->post_title] = $mcForm->ID;
                //echo(do_shortcode('[contact-form-7 id="'.$cf7Form->ID.'" title="'.($cf7Form->post_title).'"]'));
            }
        }
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Info section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
		$this->add_control(
			'phone',
			[
				'label' => __( 'Phone#', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Call Support: <strong>1-234-567-8900</strong>')
			]
		);
		$this->add_control(
			'email',
			[
				'label' => __( 'Email', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Email us: <strong>info@pet.com</strong>')
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Get Discount Codes')
			]
		);
		$this->add_control(
			'mcf',
			[
                'label' => __( 'Select Newsletter Form', 'js_composer' ),
				'type' =>\Elementor\Controls_Manager::SELECT,
                'options' => $mc_forms,
            ]
        );
        $this->end_controls_section();
 
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$mcform = '[mc4wp_form id="'.$settings['mcf'].'"]';
		?>
		<section class="info-section" style="background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)">
        <div class="auto-container clearfix">
            <ul class="info-lists">
                <li><span class="icon fa fa-phone-square"></span><?php echo esc_html($settings['phone']); ?></li>
                <li><span class="icon fa fa-envelope"></span><?php echo esc_html($settings['email']); ?></li>
                <li><span class="icon fa fa-diamond"></span><?php echo esc_html($settings['title']); ?></li>
            </ul>
            <!--Emailed Form-->
            <div class="emailed-form">
                <?php echo do_shortcode( $mcform );?>
                </div>
                </div>
    </section>
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>