<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class News_Header extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'news-header';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'News Header section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		 $categories_array = array();
$categories = get_categories();
foreach( $categories as $category ){
  $categories_array[$category->slug] = $category->name;
}
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'News Header section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'n_posts',
			[
				'label' => __( 'Number Of posts', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('3')
			]
		);
		$this->add_control(
			'cat_id',
			[
				'label' => __( 'category id', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::SELECT,
				'options' => $categories
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<?php $args = array('post_type' =>'post',
			      'category_name' => $settings['cat_id'],
		          'posts_perpage' => $settings['n_posts']); ?>
            <?php $blog_posts = new WP_Query($args); ?>
            <?php if($blog_posts->have_posts()): ?>
                    <?php while($blog_posts->have_posts()): $blog_posts->the_post(); ?>
<div class="posts ">
        <div class="header-post">
          <div class="himage">
            <span class="cat">
            <?php echo $atts['category_id']; ?>
          </span>
          <a href="<?php the_permalink(); ?>">
            <?php if (has_post_thumbnail()): ?>
              
              <?php the_post_thumbnail(); ?>
              <?php else: ?>
                <img src="<?php echo get_stylesheet_directory_uri().'/framework/assets/images/placeholder.jpg' ?>">

            <?php endif ?>
                          </a>
          </div>
          <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
          <?php if ($atts['showpostmeta']  == 'show'): ?>
            <div class="post-meta">
            <div class="post-meta-content">
              <span><i class="fa fa-user"></i> <?php the_author(); ?> </span>
              <span><i class="fa fa-comments"></i> <?php comments_number( '0 comment', '1 comment', '% comments' ); ?> </span>
            </div>
          </div>
          <?php endif ?>
          
        </div>
      </div>
      <?php endwhile; ?>
    <?php endif; ?>
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>