<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class Packages_Section extends \Elementor\Widget_Base {

	public function get_name() {
		return 'package';
	}

	public function get_title() {
		return __( 'Package section', 'elementor' );
	}
	public function get_categories() {
		return [ 'custom' ];
	}

	protected function register_controls() {
		  $this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Package section setting', 'petenica-core' ),
			]
		   );
		  $this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url'=>'',
				],
				'show' => 'false',
			]
		);
		  $this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Our Pricing List')
			]
		   );
		  $this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('For professional dog and cat grooming needs')
			]
		  );
	    $this->end_controls_section();

	    //Start repetor control

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Set Prices', 'plugin-name' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Prices setting', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'List Title' , 'petenica-core' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'title', [
				'label' => __( 'Title', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Standard' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'price', [
				'label' => __( 'Price', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '$25' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'price_per', [
				'label' => __( 'Price per', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '/ Visit' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'features', [
				'label' => __( 'Features', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => __( '<li>Bath Spa &amp; Brush </li>
                                  <li> Trim &amp; Grooming </li>
                                  <li> Cleaning &amp; Plucking </li>
                                  <li> Pick n Drop Service</li>' , 
                                  'petenica-core' ),
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'btn_link',
			[
				'label' => __( 'Button url', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$repeater->add_control(
			'btn_text', [
				'label' => __( 'Button Title', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Details' , 'petenica-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'list_color',
			[
				'label' => __( 'Color', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}'
				],
			]
		);
		$this->add_control(
			'list',
			[
				'label' => __( 'Repeater List', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __( 'Title 1', 'petenica-core' ),
						'list_content' => __( 'Item content. Click the edit button to change this text.', 'petenica-core' ),
					],
					[
						'list_title' => __( 'Title 2', 'petenica-core' ),
						'list_content' => __( 'Item content. Click the edit button to change this text.', 'petenica-core' ),
					],
					[
						'list_title' => __( 'Title 3', 'petenica-core' ),
						'list_content' => __( 'Item content. Click the edit button to change this text.', 'petenica-core' ),
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<section class="pricing-section" style="background-image:url(<?php echo esc_html($settings['bg_image']['url']); ?>)">
        <div class="auto-container">
            <!--Sec Title Two-->
            <div class="sec-title-two light centered">
                <div class="title-icon">
                    <img src="<?php echo get_template_directory_uri(); ?>/framework/assets/images/icons/title-icon.png" alt="img">
                </div>
                <h2><?php echo esc_html($settings['title']); ?></h2>
                <div class="text"><?php echo esc_html($settings['s_title']); ?></div>
            </div>
            <div class="inner-container">
                <div class="row clearfix">
                	<?php if( $settings['list'] ) {
                		foreach($settings['list'] as $item) {?>
                    <div class="price-block-two col-md-4 col-sm-6 col-xs-12">
                        <div class="inner-box">
                            <div class="title"><?php echo esc_html( $item['title']); ?></div>
                            <div class="price"><?php echo esc_html($item['price']); ?><span><?php echo esc_html($item['price_per']); ?></span></div>
                            <ul>
                                <li><span>Includes:</span></li>
                                <?php echo esc_html($item['features']); ?>                                
                            </ul>
                            <a href="<?php echo esc_html($item['btn_link']); ?>" class="theme-btn btn-style-seven"><?php echo esc_html($item['btn_text']); ?></a>
                        </div>
                    </div>
                <?php }} ?>
                </div>
            </div>
        </div>
    </section>
	<?php }

	protected function _content_template() {
		?>
		<# if ( settings.list.length ) { #>
		<dl>
			<# _.each( settings.list, function( item ) { #>
				<dt class="elementor-repeater-item-{{ item._id }}">{{{ item.list_title }}}</dt>
				<dd>{{{ item.list_content }}}</dd>
			<# }); #>
			</dl>
		<# } #>
		<?php
	}
}