<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Product_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'product-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Product section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Product section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Recent Products')
			]
		);
		$this->add_control(
			'ppp',
			[
				'label' => __( 'product per page', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('4')
			]
		   );
		$this->add_control(
			'order',
			[
				'label' => __( 'Order by', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC' => 'Ascending',
                      'DESC'    =>    'Descending '
				],
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
	    <section class="products-section">
        <div class="auto-container">
            <!--Sec Title Two-->
            <div class="sec-title-two centered">
                <div class="title-icon">
                    <img src="<?php echo get_template_directory_uri(); ?>/framework/assets/images/icons/title-icon.png" alt="img">
                </div>
                <h2><?php echo esc_html($settings['title']); ?></h2>
            </div>
            <?php $args = array('post_type' => 'product',
	                        'posts_per_page' => '4'); 
            $product_item = isset($product_item) ? $product_item : 'inner';
            $posts = new WP_Query(array(
                'post_type' => 'product',
                'posts_per_page' => $settings['ppp'],
                'order' => $settings['order'],
            ));?>
	        <?php $posts = new WP_Query($args); ?>
            <div class="row clearfix products-grid">
            	<?php
                $i = 1;
                 while ($posts->have_posts()) : $posts->the_post();
                    global $product;
                ?>
                <div class="col-md-3">
                    <?php wc_get_template_part( 'item-product/'.$product_item ); ?>
                </div>
                
                <?php
                    $i++;
                endwhile;
                wp_reset_postdata();
                ?>    

            </div>
        </div>
    </section>                   
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>