<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Servicesvet_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'servicesvet';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Services Vet section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Services Vet section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'ppp',[
				'type' => \Elementor\Controls_Manager::TEXT,
                'label' => esc_html__('Posts show count', 'petenica-core'),
                'value' => 3,
			]
                
        );
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Our Services')
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('For professional dog and cat grooming needs')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		

		$posts = new WP_Query(array(
                    'post_type' => 'petenica_service',
                    'posts_per_page' => $settings['ppp']
        
                    ));
    ?>
    <section class="what-we-offer section-padding">
            <div class="container">
                <!--Sec Title-->
                <div class="sec-title centered">
                    <div class="separator">
                        <span class="icon flaticon-pawprint-1"></span>
                    </div>
                    <div class="title"><?php echo $settings['subtitle']; ?></div>
                    <h2><?php echo $settings['title']; ?></h2>
                </div>
                <div class="row">
                    <?php    if ($posts->have_posts()) { $count = 1;
                    while ($posts->have_posts()) {
                        $posts->the_post();
                        $serviceicon = get_post_meta(get_the_ID() ,'petenica_meta_icon', true );
                ?>  <!--Services Block-->
                    <div class="col-md-4 col-sm-6 col-xs-12">
                        <div class="single-what-we-offer hvr-bounce-to-bottom">
                            <i class="icon <?php echo $serviceicon; ?>"></i>
                            <h3><?php the_title(); ?></h3>
                            <p><?php echo petenica_substring( get_the_excerpt(), 13, '...' ); ?></p>
                            <a href="<?php the_permalink(); ?>" class="read-more"><i class="fa fa-angle-right"></i></a>
                        </div><!-- /.single-what-we-offer -->
                    </div><!-- /.col-md-4 -->
                    <?php if ($count % 3 == 0): ?>
                        <div class="clearfix"></div>
                    <?php endif ?>
                     <?php $count++; }  
                } ?>
                   
                </div><!-- /.row -->
            </div><!-- /.container -->
        </section><!-- /.what-we-offer -->
		<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<div class="title">
			{{{ settings.title }}}
		</div>
		<?php
	}
}
 ?>