<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Show_Pets extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'show-pets';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Show Pets', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		 $categories_array = array('select' => '');
    $categories = get_categories(array('taxonomy' => 'pet-type',));
    foreach( $categories as $category ) {
        $categories_array[$category->slug] = $category->name;
    }

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Show Pets setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'ppp',[
				'type' => \Elementor\Controls_Manager::TEXT,
                'label' => esc_html__('Pets per page', 'petenica-core'),
                'default' => 3,
			]
                
        );
        
		$this->add_control(
			'order',[
				'type' => \Elementor\Controls_Manager::SELECT,
                'label' => esc_html__('Post order', 'petenica-core'),
                'options' => [
                		'ASC' => 'Ascending',
                    	'DESC' => 'Descending',
                ]
            ]
        );


        $this->add_control(
      'showfpets',[
        'label' => 'Show Featured Pets',
        'type' => \Elementor\Controls_Manager::SELECT, 
          'param_name'    => 'showfpets',
          'options'         => [
            'Select'  => 'none',
            'isfeatured'=>'Show Only Featured Pet'   ,
            'allpets'=> 'Show All Pets'                          
            ], // here I'm stuck
        ]
      );

        $this->add_control(
			'category_id',[
				'type' => \Elementor\Controls_Manager::SELECT, 
          'options'         => $categories_array,//get_custom_terms( 'pet-type'), // here I'm stuck
          'label'       => __('Category filter:', 'overmax'),
          ]
        );
        $this->add_control(
        	'showpetdata',[
          		'type'          => \Elementor\Controls_Manager::SELECT,
          		'options'         => [
            			'Select ' => '',
            		'show' => 'Show',
            		'hide' => 'Hide'
                      ], // here I'm stuck
          		'label'       => __('Show Hide pet data', 'overmax'),
      		]
         
        );
      $this->add_control(
        'read_more',[
          'type' => \Elementor\Controls_Manager::TEXT,
      
            'label' => esc_html__('Read more link label', 'petenica-core'),
            'default' => 'More Details'
          ]
      );
		
		
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$posts_per_page = $settings['ppp'];
  if ($posts_per_page == 0) {
    $posts_per_page = 1;
  }
  
  $posts = new WP_Query(array(
    'post_type' => 'petenicapet',
    'posts_per_page' => $posts_per_page,
    //'category_name' => $settings['category_id'],
    'tax_query' => array(
      array(
        'taxonomy' => 'pet-type',
        'field' => 'slug',
        'terms' => array(  $settings['category_id'] ),
      ),

    )

  ));
  ?>
  <div class="container">
    <div class="row">
      
  <?php
  $i = 1;
  while ($posts->have_posts()) : $posts->the_post();
    $isfeatured = get_post_meta( get_the_ID(), 'petenica_meta_isfeatured', true ); 
    $images = get_post_meta( get_the_ID(), 'petenica_meta_pet_images', 1);
    ?>

    <?php if ($i<=$posts_per_page ): ?>

      <?php if ($settings['showfpets'] == 'isfeatured'&& $isfeatured): ?>



       <div class="posts pfeatured">
        <div class="header-post">
          <div class="himage">
            <span class="featured">
              <?php esc_html_e( 'Featured ','petenica-core' ); echo $settings['category_id']; ?>
            </span>
            <a href="<?php the_permalink(); ?>">
              <?php if (!empty($images)): ?>


               <?php 
               $count = 1; 
               foreach ($images as $id => $url) {            
                if ($count == 1) {
                  echo  wp_get_attachment_image( $id, 'petenica-feauredpet' );
                  $count++;
                }
              }
              ?>
            <?php endif ?>
          </a>
        </div>
        <?php if ($settings['showpetdata']  == 'show'): ?>
          <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

          <div class="post-meta">
            <div class="post-meta-content">
              <span><i class="fa fa-user"></i> <?php the_author(); ?> </span>
              <span><i class="fa fa-comments"></i> <?php comments_number( '0 comment', '1 comment', '% comments' ); ?> </span>
            </div>
          </div>
        <?php endif ?>

      </div>
    </div> 
    <?php elseif($settings['showfpets'] == 'allpets'): ?>
      <div class="posts col-md-4">
        <div class="header-post">
          <div class="himage">
            <span class="cat">
              <?php echo $settings['category_id']; ?>
            </span>
            <a href="<?php the_permalink(); ?>">
              <?php if (!empty($images)): ?>


               <?php 
               $count = 1; 
               foreach ($images as $id => $url) {            
                if ($count == 1) {
                  echo  wp_get_attachment_image( $id, 'petenica-pets' );
                  $count++;
                }
              }
              ?>
            <?php endif ?>
          </a>
        </div>
        <?php if ($settings['showpetdata']  == 'show'): ?>
          <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

          <div class="lower-content">
            <ul>
                                <?php $pettype =  get_the_term_list( $post->ID, 'pet-type', '', ', ' ); ?>
                                <?php if (!empty($pettype)): ?>
                                    <li><?php esc_html_e( 'Pet Type','petenica-core'); ?>: <strong><?php echo get_the_term_list( $post->ID, 'pet-type', '', ', ' );?></strong></li>
                                <?php endif ?>                                
                                 <?php $pet_breed =  get_the_term_list( $post->ID, 'pet-breed', '', ', ' ); ?>
                                <?php if (!empty($pet_breed)): ?>
                                    <li><?php esc_html_e( 'Bread','petenica-core'); ?>: <strong><?php echo get_the_term_list( $post->ID, 'pet-breed', '', ', ' );?></strong></li>
                                <?php endif ?>
                                 <?php $petlocation =  get_the_term_list( $post->ID, 'pet-location', '', ', ' ); ?>
                                <?php if (!empty($petlocation)): ?>
                                    <li><?php esc_html_e( 'Location','petenica-core'); ?>: <strong><?php echo  get_the_term_list( $post->ID, 'pet-location', '', ', ' ); ?></strong></li>
                                <?php endif ?>  
                            </ul>
                            
            
          </div>
        <?php endif ?>

      </div>
    </div> 
  <?php endif ?>
<?php endif ?>
<?php 

$i++;
endwhile;
wp_reset_postdata();
?>    

    </div>
  </div>
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>