<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Team2_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'team2-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team2 Section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Team 2 section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'ppp',[
				'type' => \Elementor\Controls_Manager::TEXT,
                'label' => esc_html__('Posts show count', 'petenica-core'),
                'default' => 3,
			]
                
        );
        
		$this->add_control(
			'order',[
				'type' => \Elementor\Controls_Manager::SELECT,
                'label' => esc_html__('Post order', 'petenica-core'),
                'options' => [
                		'ASC' => 'Ascending',
                    	'DESC' => 'Descending',
                ]
            ]
                    
                
            );
		$this->add_control(
			'bg_image',
			[
				'label' => __( 'Background Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => '',
				],
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Our Team Members')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Because We Really Care About Your Pets')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
<section class="counter-section experienced-dr">
    <div class="auto-container">
        <div class="image-layer" style="background-image:url(<?php echo esc_url($settings['bg_image']['url']); ?>)"></div>
        <h2>
            <?php echo esc_html($settings['title']); ?><span>
                <?php echo esc_html($settings['s_title']); ?></span></h2>
        <div class="fact-counter">
            <div class="row clearfix">
                <div class="">
                    <div class="auto-container">
                        <?php $args = array('post_type' => 'petenica_team',
                                        'posts_per_page' => $settings['ppp'],
        'order' => $settings['order'],); ?>
                        <?php $team_posts = new WP_Query ($args); ?>
                        <?php if($team_posts->have_posts()): ?>
                        <?php while($team_posts->have_posts()): $team_posts->the_post();
                                    $fb = get_post_meta(get_the_ID() ,'petenica_meta_facebook', true );
                                    $twitter = get_post_meta(get_the_ID() ,'petenica_meta_twitter', true );
                                    $dribble = get_post_meta(get_the_ID() ,'petenica_meta_dribble', true );
                                    $gplus = get_post_meta(get_the_ID() ,'petenica_meta_gplus', true );
                                    ?>
                        <!--Team Block-->
                        <div class="team-block col-md-3 col-sm-4 col-xs-12 wow fadeInUp" data-wow-duration="1500ms" data-wow-delay="0ms">
                            <div class="inner-box">
                                <div class="image">
                                    <a href="<?php the_permalink(); ?>">
                                        <?php the_post_thumbnail(); ?></a>
                                </div>
                                <div class="lower-box">
                                    <h3><a href="<?php the_permalink(); ?>">
                                            <?php the_title(); ?></a></h3>
                                    <div class="designation">
                                        <?php echo get_post_meta( get_the_ID(), 'petenica_meta_designation' , true ); ?>
                                    </div>
                                    <div class="social-box">
                                        <ul class="social-icon-one">
                                            <?php
                                                        if(!empty($fb)) echo '<li><a href="'.$fb.'" class="tran3s"><span class="fa fa-facebook" aria-hidden="true"></span></a></li>';
                                                        if(!empty($twitter)) echo '<li><a href="'.$twitter.'" class="tran3s"><span class="fa fa-twitter" aria-hidden="true"></span></a></li>';
                                                        if(!empty($dribbble)) echo '<li><a href="'.$dribbble.'" class="tran3s"><span class="fa fa-dribbble" aria-hidden="true"></span></a></li>';
                                                        if(!empty($gplus)) echo '<li><a href="'.$gplus.'" class="tran3s"><span class="fa fa-google-plus" aria-hidden="true"></span></a></li>';
                                                        ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>