<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Team4_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'team4-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team4 Section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Team 4 section setting', 'petenica-core' ),
			]
		);
		$this->add_control(
			'ppp',[
				'type' => \Elementor\Controls_Manager::TEXT,
                'label' => esc_html__('Posts show count', 'petenica-core'),
                'default' => 3,
			]
                
        );
        
		$this->add_control(
			'order',[
				'type' => \Elementor\Controls_Manager::SELECT,
                'label' => esc_html__('Post order', 'petenica-core'),
                'options' => [
                		'ASC' => 'Ascending',
                    	'DESC' => 'Descending',
                ]
            ]
                    
                
            );
		
		$this->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'icon flaticon-two-dog-pawprints' => 'two-dog-pawprints',
                        'icon flaticon-face-of-staring-dog' => 'face-of-staring-dog',
                        'icon flaticon-van' => 'van',
                        'icon flaticon-truck' => 'truck',
                        'icon flaticon-dog-bone' => 'dog-bone',
                        'icon flaticon-bone' => 'bone',
                        'icon flaticon-dog-3' => 'dog-3',
                        'icon flaticon-rabbit' => 'rabbit',
                        'icon flaticon-easter-bunny' => 'easter-bunny',
                        'icon flaticon-animals-3' => 'animals-3',
                        'icon flaticon-animals-2' => 'animals-2',
                        'icon flaticon-pets-hotel-house-sign-with-a-paw' => 'pets-hotel-house-sign-with-a-paw',
                        'icon flaticon-dog-in-front-of-a-man' => 'dog-in-front-of-a-man',
                        'icon flaticon-man' => 'man',
                        'icon flaticon-pawprint' => 'pawprint',
                        'icon flaticon-pawprint-1' => 'pawprint-1',
                        'icon flaticon-animals-1' => 'animals-1',
                        'icon flaticon-dog-2' => 'dog-2',
                        'icon flaticon-cat' => 'cat',
                        'icon flaticon-dog-1' => 'dog-1',
                        'icon flaticon-award' => 'award',
                        'icon flaticon-medal' => 'medal',
                        'icon flaticon-animal-3' => 'animal-3',
                        'icon flaticon-animal-2' => 'animal-2',
                        'icon flaticon-animals' => 'animals',
                        'icon flaticon-brush' => 'brush',
                        'icon flaticon-animal-1' => 'animal-1',
                        'icon flaticon-dog' => 'dog',
                        'icon flaticon-animal' => 'animal',
                        'icon flaticon-siberian-husky' => 'siberian-husky',
                        'icon flaticon-pet-grooming' => 'pet-grooming',
				],
				'default' => 'icon flaticon-pawprint-1',
			]
		);
		// $this->add_control(
		// 	'bg_image',
		// 	[
		// 		'label' => __( 'Background Image', 'petenica-core' ),
		// 		'type' => \Elementor\Controls_Manager::MEDIA,
		// 		'default' => [
		// 		'url' => \Elementor\Utils::get_placeholder_image_src('http://localhost/learnwp/wp-content/uploads/2020/01/4-1.jpg'),
		// 		],
		// 	]
		// );
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Our Team Members')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Because We Really Care About Your Pets')
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
<section class="team-section">
    	<div class="auto-container">
        	<!--Sec Title-->
            <div class="sec-title centered">
            	<div class="separator">
                    <span class="<?php echo esc_html($settings['icon']); ?>"></span>
                </div>
                <div class="title"><?php echo esc_html($settings['s_title']); ?></div>
                <h2><?php echo esc_html($settings['title']); ?></h2>
            </div>
            <div class="row clearfix">        
                <?php $args = array('post_type' => 'petenica_team',
                                        'posts_per_page' => $settings['ppp'],
        'order' => $settings['order'],); ?>
                        <?php $team_posts = new WP_Query ($args); ?>
                        <?php if($team_posts->have_posts()): ?>
                        <?php while($team_posts->have_posts()): $team_posts->the_post();               
                $fb = get_post_meta(get_the_ID() ,'petenica_meta_facebook', true );
                $twitter = get_post_meta(get_the_ID() ,'petenica_meta_twitter', true );
                $dribble = get_post_meta(get_the_ID() ,'petenica_meta_dribble', true );
                $gplus = get_post_meta(get_the_ID() ,'petenica_meta_gplus', true );
                ?>
                <div class="col-md-6">
                    <div class="team-block3">
                        <div class="row">
                    <div class="col-md-4">
                        <div class="unit-left"><?php the_post_thumbnail(); ?>
                  </div>
                    </div>                      
                  <div class="col-md-8">
                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                    <div class="designation"><?php echo get_post_meta( get_the_ID(), 'petenica_meta_designation' , true ); ?></div>                   
                      <div class="phoneno"><a class="h6" href="tel:#"><i class="fa fa-phone"></i> <?php echo get_post_meta( get_the_ID(), 'petenica_meta_emergency', true );?></a></div>                    
                    <p><?php echo petenica_substring( get_the_excerpt(), 15, '...' ); ?></p>
                  </div>
                </div>
                    </div>                
              </div>
                 <!--Team Block-->                                        
                <?php endwhile; ?>
                        <?php endif; ?>
                      
            </div>
        </div>
    </section>
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>