<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Testimonial_Section extends \Elementor\Widget_Base {

	public function get_name() {
		return 'testimonial';
	}

	public function get_title() {
		return __( 'Testimonial', 'elementor' );
	}
	public function get_categories() {
		return [ 'custom' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Testimonial', 'petenica-core' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Read Testimonials')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Because We Really Care About Your Pets')
			]
		);
	$this->end_controls_section();

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Testimonial section', 'plugin-name' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Testimonial section setting', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'List Title' , 'petenica-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'text', [
				'label' => __( 'Text', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => __( 'And taped a amazingly lazily far gosh oh bald oh raffishly ouch ladybug far that the and alas slapped alas far brusque pridefully kneeled python horse alas sound because more prodigiously outgrew tortoise characteristic stupidly  barring therefore so sniffed before drank.' , 'petenica-core' ),
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'_image',
			[
				'label' => __( 'Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src('http://localhost/learnwp/wp-content/uploads/2020/01/4-1.jpg'),
				],
				'show' => 'false',
			]
		);
		$repeater->add_control(
			'name', [
				'label' => __( 'Name', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Tina Cambell' , 'petenica-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'designition', [
				'label' => __( 'Designation', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'pet owner' , 'petenica-core' ),
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Repeater List', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		
		?>
		 <section class="testimonial-section">
            <div class="auto-container">
                <!--Sec Title-->
                <div class="sec-title centered">
                    <div class="separator">
                        <span class="icon flaticon-pawprint-1"></span>
                    </div>
                    <div class="title"><?php echo esc_html($settings['s_title']); ?></div>
                    <h2><?php echo esc_html($settings['title']); ?></h2>
                </div>
                <div class="testimonials-item-carousel owl-carousel owl-theme">
                	<?php if ( $settings['list'] ) {
			              foreach (  $settings['list'] as $item ) {?>
                    <!--Testimonial Block-->
                    <div class="testimonial-block">
                        <div class="inner-box">
                            <div class="quote-icon">
                                <span class="icon flaticon-quotation-marks"></span>
                            </div>
                            <div class="text">
                          <?php  
			              	echo esc_html($item ['text']);
			              ?>
                            </div>
                            <div class="author-image">
                               <img src="<?php echo esc_html($item['_image']['url']); ?>"> 
                            </div>
                                <div class="author-name"><?php 
                                		echo esc_html($item['name']);
                                	 ?></div>
                                <div class="designation"> <?php 
                                		echo esc_html($item['designition']);
                                	 ?></div>
                            </div>
                        </div>
                    <?php }} ?>
                            </div>
                        </div>
                    </section>
		<?php
	}

	protected function _content_template() {
		?>
		<# if ( settings.list.length ) { #>
		<dl>
			<# _.each( settings.list, function( item ) { #>
				<dt class="elementor-repeater-item-{{ item._id }}">{{{ item.list_title }}}</dt>
				<dd>{{{ item.text }}}</dd>
			<# }); #>
			</dl>
		<# } #>
		<?php
	}
}
?>