<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Welcome2_Section extends Widget_Base {
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'welcome2-section';
	}
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Welcome2 Section', 'petenica-core' );
	}
	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'custom' ];
	}
	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'petenica-core' ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Wellcome2 section setting', 'petenica-core' ),
			]
		);
		// $this->add_control(
		// 	'a_icon',
		// 	[
		// 		'label' => __( 'Icon', 'petenica-core' ),
		// 		'type' => \Elementor\Controls_Manager::ICON,
		// 		'include' => [
		// 			'icon flaticon-pawprint-1',
		// 			'fa fa-facebook',
		// 			'fa fa-flickr',
		// 			'fa fa-google-plus',
		// 		],
		// 		'default' => 'icon flaticon-pawprint-1',
		// 	]
		// );
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Welcome to Petenica')
			]
		);
		$this->add_control(
			's_title',
			[
				'label' => __( 'Sub Title', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('Because We Really Care Welcome Your Pets')
			]
		);
		$this->add_control(
			'content',
			[
				'label' => __( 'Text', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::WYSIWYG,
				'default' => ('Broadcast neglectful and poignantly well until and some listlessly amidst suc cessful concentrically ably dachshund more far but forwardly echidna outside tiger split thanks far vibrantly gosh hence pangolin however notwithstanding leapt untruthful gauchely yikes komodo dully more.As abandoned winced this more far wow jeepers near more wow goodness so revealed much along worm some grasshopper.')
			]
		);
		$this->add_control(
			'text2',
			[
				'label' => __( 'Text2', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::WYSIWYG,
				'default' => ('<li>Abore et dolore magna aliqua ut enim veniam</li>
					           <li>Quis nostrud exercitation ullamco laboris nisi aliquip</li>
                               <li>Eiusmod tempor incididunt labore.</li>
                            ')
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => __( 'Button Link', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'petenica-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'b_text',
			[
				'label' => __( 'Button Text', 'petenica-core' ),
				'type' =>\Elementor\Controls_Manager::TEXT,
				'default' => ('view our services')
			]
		);
		$this->add_control(
			'l_image',
			[
				'label' => __( 'Chose Image', 'petenica-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src('http://localhost/petenica/wp-content/uploads/2018/03/image-1.jpg'),
				],
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
<section class="welcome-section welcome-sec-4">
        <div class="auto-container">
            <div class="row clearfix">
                <!--Image Column-->
                <div class="image-column col-md-6 col-sm-12 col-xs-12 wow fadeInLeft" data-wow-duration="2000ms" data-wow-delay="0ms">
                    <div class="image">
                        <img src="<?php echo esc_url($settings['l_image']['url']); ?>" alt="" />
                    </div>
                </div>
                <!--Content Column-->
                <div class="content-column col-md-6 col-sm-12 col-xs-12 wow fadeInRight" data-wow-duration="2000ms" data-wow-delay="0ms">
                    <div class="inner-column">
                        <h1><?php echo esc_html($settings['title']); ?></h1>
                        <h3><?php echo esc_html($settings['s_title']); ?></h3>
                        <div class="text">
                            <p><?php echo esc_html($settings['content']); ?></p>
                        </div>
                        <?php echo $content; ?>
                        <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" class="theme-btn"><?php echo esc_html($settings['b_text']); ?></a>
                    </div>
                </div>
                
            </div>
        </div>
    </section>
<?php
	}
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
<div class="title">
    {{{ settings.title }}}
</div>
<?php
	}
}
 ?>