<?php 
class Plugin {
	/**
	 * Instance
	 * 
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;
	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_register_script( 'petenica-core', plugins_url( '/assets/js/hello-world.js', __FILE__ ), [ 'jquery' ], false, true );
	}
	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/welcome-widget.php' );
		require_once( __DIR__ . '/widgets/feature-widget.php' );
		require_once( __DIR__ . '/widgets/services-widget.php' );
		require_once( __DIR__ . '/widgets/appointment-widget.php' );
		require_once( __DIR__ . '/widgets/team-widget.php' );
		require_once( __DIR__ . '/widgets/counter-widget.php' );
		require_once( __DIR__ . '/widgets/adoptionpets-widget.php' );
		require_once( __DIR__ . '/widgets/about-video-widget.php' );
		require_once( __DIR__ . '/widgets/testimonial-widget.php' );
		require_once( __DIR__ . '/widgets/blogpost-widget.php' );
		require_once( __DIR__ . '/widgets/donation-widget.php' );
		require_once( __DIR__ . '/widgets/services2-widget.php' );
		require_once( __DIR__ . '/widgets/services3-widget.php' );
		require_once( __DIR__ . '/widgets/mission-widget.php' );
		require_once( __DIR__ . '/widgets/petgrooming-widget.php' );
		require_once( __DIR__ . '/widgets/package-widget.php' );
		require_once( __DIR__ . '/widgets/newsletter-widget.php' );
		require_once( __DIR__ . '/widgets/gallery-widget.php' );
		require_once( __DIR__ . '/widgets/product-widget.php' );
		require_once( __DIR__ . '/widgets/dealproduct-widget.php' );
		require_once( __DIR__ . '/widgets/productfilter-widget.php' );
		require_once( __DIR__ . '/widgets/feature2-widget.php' );
		require_once( __DIR__ . '/widgets/info-widget.php' );
		require_once( __DIR__ . '/widgets/contact-widget.php' );
		require_once( __DIR__ . '/widgets/map-widget.php' );
	}
	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();
		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Welcome_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Feature_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Services_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Appointment_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Team_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Counter_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Adoption_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new About_Video_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Testimonial_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Blogpost_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Donation_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Services2_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Services3_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Mission_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new pet_Grooming_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Packages_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Newsletter_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Gallery_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Product_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Deal_Product_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Filter_Product_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Feature2_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Info_Section() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Contact_Form() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Map() );
		//\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Inline_Editing() );
	}
	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {
		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );
		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}
// Instantiate Plugin Class
Plugin::instance();
 ?>