<?php 
/**
 * Adds Foo_Widget widget.
 */
class Contact_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'contact_widget', // Base ID
			esc_html__( 'Contact', 'text_domain' ), // Name
			array( 'description' => esc_html__( 'Contact Widget', 'text_domain' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}
		echo '<ul class="contact-info">
                    <li><span class="icon fa fa-map-marker"></span>'.$instance['caddress'].'</li>
                    <li><span class="icon fa fa-phone"></span>'.$instance['phno'].'</li>
                    <li><span class="icon fa fa-envelope"></span>'.$instance['email'].'</li>
                </ul>';
		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'New title', 'text_domain' );
		$caddress = ! empty( $instance['caddress'] ) ? $instance['caddress'] : esc_html__( 'BellSouth, Harley Street Florida 33968', 'text_domain' );
		$phno = ! empty( $instance['phno'] ) ? $instance['phno'] : esc_html__( '+(1) 234 567 8900', 'text_domain' );
		$email = ! empty( $instance['email'] ) ? $instance['email'] : esc_html__( 'example@exmaple.com', 'text_domain' );
		?>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'text_domain' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'caddress' ) ); ?>"><?php esc_attr_e( 'Address:', 'text_domain' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'caddress' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'caddress' ) ); ?>" type="text" value="<?php echo esc_attr( $caddress ); ?>">
		</p>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'phno' ) ); ?>"><?php esc_attr_e( 'Phone No:', 'text_domain' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phno' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phno' ) ); ?>" type="text" value="<?php echo esc_attr( $phno ); ?>">
		</p>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>"><?php esc_attr_e( 'Email:', 'text_domain' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email' ) ); ?>" type="text" value="<?php echo esc_attr( $email ); ?>">
		</p>
		<?php 
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['caddress'] = ( ! empty( $new_instance['caddress'] ) ) ? strip_tags( $new_instance['caddress'] ) : '';
		$instance['phno'] = ( ! empty( $new_instance['phno'] ) ) ? strip_tags( $new_instance['phno'] ) : '';
		$instance['email'] = ( ! empty( $new_instance['email'] ) ) ? strip_tags( $new_instance['email'] ) : '';
		return $instance;
	}

} // class Foo_Widget

function register_contact_widget() {
    register_widget( 'Contact_Widget' );
}
add_action( 'widgets_init', 'register_contact_widget' );

 ?>